@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1995, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1995, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -22,11 +22,13 @@
  * or visit www.oracle.com if you need additional information or have any
  * questions.
  */
+
 package java.awt;
 
 import java.awt.peer.TextAreaPeer;
 import java.io.IOException;
 import java.io.ObjectInputStream;
+import java.io.Serial;
 import java.util.HashSet;
 import java.util.Set;
 
@@ -53,7 +55,7 @@ import javax.accessibility.AccessibleStateSet;
  * @author      Sami Shaio
  * @since       1.0
  */
-public class TextArea extends TextComponent {
+public non-sealed class TextArea extends TextComponent {
 
     /**
      * The number of rows in the {@code TextArea}.
@@ -125,9 +127,10 @@ public class TextArea extends TextComponent {
      */
     private static Set<AWTKeyStroke> forwardTraversalKeys, backwardTraversalKeys;
 
-    /*
-     * JDK 1.1 serialVersionUID
+    /**
+     * Use serialVersionUID from JDK 1.1 for interoperability.
      */
+     @Serial
      private static final long serialVersionUID = 3692302836626095722L;
 
     /**
@@ -154,7 +157,7 @@ public class TextArea extends TextComponent {
      * This text area is created with scrollbar visibility equal to
      * {@link #SCROLLBARS_BOTH}, so both vertical and horizontal
      * scrollbars will be visible for this text area.
-     * @exception HeadlessException if
+     * @throws HeadlessException if
      *    {@code GraphicsEnvironment.isHeadless} returns true
      * @see java.awt.GraphicsEnvironment#isHeadless()
      */
@@ -170,7 +173,7 @@ public class TextArea extends TextComponent {
      * @param      text       the text to be displayed; if
      *             {@code text} is {@code null}, the empty
      *             string {@code ""} will be displayed
-     * @exception HeadlessException if
+     * @throws HeadlessException if
      *        {@code GraphicsEnvironment.isHeadless} returns true
      * @see java.awt.GraphicsEnvironment#isHeadless()
      */
@@ -188,7 +191,7 @@ public class TextArea extends TextComponent {
      * text area.
      * @param rows the number of rows
      * @param columns the number of columns
-     * @exception HeadlessException if
+     * @throws HeadlessException if
      *     {@code GraphicsEnvironment.isHeadless} returns true
      * @see java.awt.GraphicsEnvironment#isHeadless()
      */
@@ -209,7 +212,7 @@ public class TextArea extends TextComponent {
      *             string {@code ""} will be displayed
      * @param     rows      the number of rows
      * @param     columns   the number of columns
-     * @exception HeadlessException if
+     * @throws HeadlessException if
      *   {@code GraphicsEnvironment.isHeadless} returns true
      * @see java.awt.GraphicsEnvironment#isHeadless()
      */
@@ -249,7 +252,7 @@ public class TextArea extends TextComponent {
      * @param      scrollbars  a constant that determines what
      *             scrollbars are created to view the text area
      * @since      1.1
-     * @exception HeadlessException if
+     * @throws HeadlessException if
      *    {@code GraphicsEnvironment.isHeadless} returns true
      * @see java.awt.GraphicsEnvironment#isHeadless()
      */
@@ -418,7 +421,7 @@ public class TextArea extends TextComponent {
      * @param       rows   the number of rows
      * @see         #getRows()
      * @see         #setColumns(int)
-     * @exception   IllegalArgumentException   if the value
+     * @throws   IllegalArgumentException   if the value
      *                 supplied for {@code rows}
      *                 is less than {@code 0}
      * @since       1.1
@@ -449,7 +452,7 @@ public class TextArea extends TextComponent {
      * @param       columns   the number of columns
      * @see         #getColumns()
      * @see         #setRows(int)
-     * @exception   IllegalArgumentException   if the value
+     * @throws   IllegalArgumentException   if the value
      *                 supplied for {@code columns}
      *                 is less than {@code 0}
      * @since       1.1
@@ -649,11 +652,16 @@ public class TextArea extends TextComponent {
 
     /**
      * Read the ObjectInputStream.
-     * @exception HeadlessException if
-     * {@code GraphicsEnvironment.isHeadless()} returns
-     * {@code true}
+     *
+     * @param  s the {@code ObjectInputStream} to read
+     * @throws ClassNotFoundException if the class of a serialized object could
+     *         not be found
+     * @throws IOException if an I/O error occurs
+     * @throws HeadlessException if {@code GraphicsEnvironment.isHeadless()}
+     *         returns {@code true}
      * @see java.awt.GraphicsEnvironment#isHeadless
      */
+    @Serial
     private void readObject(ObjectInputStream s)
       throws ClassNotFoundException, IOException, HeadlessException
     {
@@ -714,11 +722,17 @@ public class TextArea extends TextComponent {
      */
     protected class AccessibleAWTTextArea extends AccessibleAWTTextComponent
     {
-        /*
-         * JDK 1.3 serialVersionUID
+        /**
+         * Use serialVersionUID from JDK 1.3 for interoperability.
          */
+        @Serial
         private static final long serialVersionUID = 3472827823632144419L;
 
+        /**
+         * Constructs an {@code AccessibleAWTTextArea}.
+         */
+        protected AccessibleAWTTextArea() {}
+
         /**
          * Gets the state set of this object.
          *
