@@ -154,7 +154,8 @@ class ZoneName {
         "America/Cayenne", "French_Guiana", "America/Cayenne",
         "America/Cayman", "America_Eastern", "America/New_York",
         "America/Chicago", "America_Central", "America/Chicago",
-        "America/Chihuahua", "Mexico_Pacific", "America/Mazatlan",
+        "America/Chihuahua", "America_Central", "America/Chicago",
+        "America/Ciudad_Juarez", "America_Mountain", "America/Denver",
         "America/Coral_Harbour", "America_Eastern", "America/New_York",
         "America/Cordoba", "Argentina", "America/Buenos_Aires",
         "America/Costa_Rica", "America_Central", "America/Chicago",
@@ -225,6 +226,7 @@ class ZoneName {
         "America/Moncton", "Atlantic", "America/Halifax",
         "America/Monterrey", "America_Central", "America/Chicago",
         "America/Montevideo", "Uruguay", "America/Montevideo",
+        "America/Montreal", "America_Eastern", "America/New_York",
         "America/Montserrat", "Atlantic", "America/Halifax",
         "America/Nassau", "America_Eastern", "America/New_York",
         "America/New_York", "America_Eastern", "America/New_York",
@@ -235,7 +237,7 @@ class ZoneName {
         "America/North_Dakota/Center", "America_Central", "America/Chicago",
         "America/North_Dakota/New_Salem", "America_Central", "America/Chicago",
         "America/Nuuk", "Greenland_Western", "America/Godthab",
-        "America/Ojinaga", "America_Mountain", "America/Denver",
+        "America/Ojinaga", "America_Central", "America/Chicago",
         "America/Panama", "America_Eastern", "America/New_York",
         "America/Pangnirtung", "America_Eastern", "America/New_York",
         "America/Paramaribo", "Suriname", "America/Paramaribo",
@@ -293,7 +295,6 @@ class ZoneName {
         "Arctic/Longyearbyen", "Europe_Central", "Europe/Paris",
         "Asia/Aden", "Arabian", "Asia/Riyadh",
         "Asia/Almaty", "Kazakhstan_Eastern", "Asia/Almaty",
-        "Asia/Amman", "Europe_Eastern", "Europe/Bucharest",
         "Asia/Anadyr", "Anadyr", "Asia/Anadyr",
         "Asia/Aqtau", "Kazakhstan_Western", "Asia/Aqtobe",
         "Asia/Aqtobe", "Kazakhstan_Western", "Asia/Aqtobe",
@@ -314,7 +315,6 @@ class ZoneName {
         "Asia/Chungking", "China", "Asia/Shanghai",
         "Asia/Colombo", "India", "Asia/Calcutta",
         "Asia/Dacca", "Bangladesh", "Asia/Dhaka",
-        "Asia/Damascus", "Europe_Eastern", "Europe/Bucharest",
         "Asia/Dhaka", "Bangladesh", "Asia/Dhaka",
         "Asia/Dili", "East_Timor", "Asia/Dili",
         "Asia/Dubai", "Gulf", "Asia/Dubai",
@@ -467,6 +467,7 @@ class ZoneName {
         "Europe/Jersey", "GMT", "Atlantic/Reykjavik",
         "Europe/Kaliningrad", "Europe_Eastern", "Europe/Bucharest",
         "Europe/Kiev", "Europe_Eastern", "Europe/Bucharest",
+        "Europe/Kyiv", "Europe_Eastern", "Europe/Bucharest",
         "Europe/Lisbon", "Europe_Western", "Atlantic/Canary",
         "Europe/Ljubljana", "Europe_Central", "Europe/Paris",
         "Europe/London", "GMT", "Atlantic/Reykjavik",
@@ -717,9 +718,7 @@ class ZoneName {
         "Europe_Eastern", "EG", "Africa/Cairo",
         "Europe_Eastern", "FI", "Europe/Helsinki",
         "Europe_Eastern", "GR", "Europe/Athens",
-        "Europe_Eastern", "JO", "Asia/Amman",
         "Europe_Eastern", "LB", "Asia/Beirut",
-        "Europe_Eastern", "SY", "Asia/Damascus",
         "Europe_Further_Eastern", "RU", "Europe/Kaliningrad",
         "Europe_Western", "FO", "Atlantic/Faeroe",
         "GMT", "BF", "Africa/Ouagadougou",
@@ -840,8 +839,11 @@ class ZoneName {
         "America/Montreal", "America/Toronto",
         "America/Montserrat", "America/Puerto_Rico",
         "America/Nassau", "America/Toronto",
+        "America/Nipigon", "America/Toronto",
+        "America/Pangnirtung", "America/Iqaluit",
         "America/Port_of_Spain", "America/Puerto_Rico",
         "America/Porto_Acre", "America/Rio_Branco",
+        "America/Rainy_River", "America/Winnipeg",
         "America/Rosario", "America/Argentina/Cordoba",
         "America/Santa_Isabel", "America/Tijuana",
         "America/Shiprock", "America/Denver",
@@ -850,8 +852,10 @@ class ZoneName {
         "America/St_Lucia", "America/Puerto_Rico",
         "America/St_Thomas", "America/Puerto_Rico",
         "America/St_Vincent", "America/Puerto_Rico",
+        "America/Thunder_Bay", "America/Toronto",
         "America/Tortola", "America/Puerto_Rico",
         "America/Virgin", "America/Puerto_Rico",
+        "America/Yellowknife", "America/Edmonton",
         "Antarctica/DumontDUrville", "Pacific/Port_Moresby",
         "Antarctica/McMurdo", "Pacific/Auckland",
         "Antarctica/South_Pole", "Pacific/Auckland",
@@ -943,9 +947,11 @@ class ZoneName {
         "Europe/Skopje", "Europe/Belgrade",
         "Europe/Stockholm", "Europe/Berlin",
         "Europe/Tiraspol", "Europe/Chisinau",
+        "Europe/Uzhgorod", "Europe/Kyiv",
         "Europe/Vaduz", "Europe/Zurich",
         "Europe/Vatican", "Europe/Rome",
         "Europe/Zagreb", "Europe/Belgrade",
+        "Europe/Zaporozhye", "Europe/Kyiv",
         "GB", "Europe/London",
         "GB-Eire", "Europe/London",
         "GMT", "Etc/GMT",
