@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2003, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -222,9 +222,9 @@ public class TagletWriterImpl extends TagletWriter {
         DocTree searchTerm = tag.getSearchTerm();
         String tagText = (searchTerm instanceof TextTree tt) ? tt.getBody() : "";
         if (tagText.charAt(0) == '"' && tagText.charAt(tagText.length() - 1) == '"') {
-            tagText = tagText.substring(1, tagText.length() - 1)
-                             .replaceAll("\\s+", " ");
+            tagText = tagText.substring(1, tagText.length() - 1);
         }
+        tagText = tagText.replaceAll("\\s+", " ");
 
         Content desc = htmlWriter.commentTagsToContent(element, tag.getDescription(), context.within(tag));
         String descText = extractText(desc);
@@ -297,14 +297,12 @@ public class TagletWriterImpl extends TagletWriter {
         }
 
         DocTree.Kind kind = tag.getKind();
-        String tagName = ch.getTagName(tag);
         String refSignature = ch.getReferencedSignature(linkRef);
 
         return linkSeeReferenceOutput(element,
                 tag,
                 refSignature,
                 ch.getReferencedElement(tag),
-                tagName,
                 (kind == LINK_PLAIN),
                 htmlWriter.commentTagsToContent(element, tag.getLabel(), context),
                 (key, args) -> messages.warning(ch.getDocTreePath(tag), key, args)
@@ -431,7 +429,6 @@ public class TagletWriterImpl extends TagletWriter {
             case REFERENCE -> {
                 // @see reference label...
                 CommentHelper ch = utils.getCommentHelper(element);
-                String tagName = ch.getTagName(seeTag);
                 String refSignature = ch.getReferencedSignature(ref0);
                 List<? extends DocTree> label = ref.subList(1, ref.size());
 
@@ -439,7 +436,6 @@ public class TagletWriterImpl extends TagletWriter {
                         seeTag,
                         refSignature,
                         ch.getReferencedElement(seeTag),
-                        tagName,
                         false,
                         htmlWriter.commentTagsToContent(element, label, context),
                         (key, args) -> messages.warning(ch.getDocTreePath(seeTag), key, args)
@@ -466,7 +462,6 @@ public class TagletWriterImpl extends TagletWriter {
      * @param refTree       the tree node containing the information, or {@code null} if not available
      * @param refSignature  the normalized signature of the target of the reference
      * @param ref           the target of the reference
-     * @param tagName       the name of the tag in the source, to be used in diagnostics
      * @param isLinkPlain   {@code true} if the link should be presented in "plain" font,
      *                      or {@code false} for "code" font
      * @param label         the label for the link,
@@ -479,7 +474,6 @@ public class TagletWriterImpl extends TagletWriter {
                                            DocTree refTree,
                                            String refSignature,
                                            Element ref,
-                                           String tagName,
                                            boolean isLinkPlain,
                                            Content label,
                                            BiConsumer<String, Object[]> reportWarning) {
@@ -500,7 +494,7 @@ public class TagletWriterImpl extends TagletWriter {
             if (labelContent.isEmpty()) {
                 // A non-empty label is required for fragment links as the
                 // reference target does not provide a useful default label.
-                reportWarning.accept("doclet.link.see.no_label", null);
+                htmlWriter.messages.error(ch.getDocTreePath(refTree), "doclet.link.see.no_label");
                 return invalidTagOutput(resources.getText("doclet.link.see.no_label"),
                         Optional.of(refSignature));
             }
@@ -535,10 +529,10 @@ public class TagletWriterImpl extends TagletWriter {
                     // No cross link found so print warning
                     if (!configuration.isDocLintReferenceGroupEnabled()) {
                         reportWarning.accept(
-                                "doclet.see.class_or_package_not_found",
-                                new Object[] { "@" + tagName, refSignature});
+                                "doclet.link.see.reference_not_found",
+                                new Object[] { refSignature});
                     }
-                    return htmlWriter.invalidTagOutput(resources.getText("doclet.tag.invalid", tagName),
+                    return htmlWriter.invalidTagOutput(resources.getText("doclet.link.see.reference_invalid"),
                             Optional.of(labelContent.isEmpty() ? text: labelContent));
                 }
             }
@@ -549,17 +543,17 @@ public class TagletWriterImpl extends TagletWriter {
                 if (utils.isGenericType(referencedType)) {
                     // This is a generic type link, use the TypeMirror representation.
                     return plainOrCode(isLinkPlain, htmlWriter.getLink(
-                            new HtmlLinkInfo(configuration, HtmlLinkInfo.Kind.DEFAULT, referencedType)));
+                            new HtmlLinkInfo(configuration, HtmlLinkInfo.Kind.LINK_TYPE_PARAMS_AND_BOUNDS, referencedType)));
                 }
                 labelContent = plainOrCode(isLinkPlain, Text.of(utils.getSimpleName(refClass)));
             }
-            return htmlWriter.getLink(new HtmlLinkInfo(configuration, HtmlLinkInfo.Kind.DEFAULT, refClass)
+            return htmlWriter.getLink(new HtmlLinkInfo(configuration, HtmlLinkInfo.Kind.PLAIN, refClass)
                     .label(labelContent));
         } else if (refMem == null) {
             // This is a fragment reference since refClass and refFragment are not null but refMem is null.
-            return htmlWriter.getLink(new HtmlLinkInfo(configuration, HtmlLinkInfo.Kind.SEE_TAG, refClass)
+            return htmlWriter.getLink(new HtmlLinkInfo(configuration, HtmlLinkInfo.Kind.PLAIN, refClass)
                     .label(labelContent)
-                    .where(refFragment)
+                    .fragment(refFragment)
                     .style(null));
         } else {
             // Must be a member reference since refClass is not null and refMemName is not null.
@@ -573,8 +567,9 @@ public class TagletWriterImpl extends TagletWriter {
                 VisibleMemberTable vmt = configuration.getVisibleMemberTable(containing);
                 overriddenMethod = vmt.getOverriddenMethod((ExecutableElement)refMem);
 
-                if (overriddenMethod != null)
+                if (overriddenMethod != null) {
                     containing = utils.getEnclosingTypeElement(overriddenMethod);
+                }
             }
             if (refSignature.trim().startsWith("#") &&
                     ! (utils.isPublic(containing) || utils.isLinkable(containing))) {
@@ -585,12 +580,12 @@ public class TagletWriterImpl extends TagletWriter {
                 if (htmlWriter instanceof ClassWriterImpl writer) {
                     containing = writer.getTypeElement();
                 } else if (!utils.isPublic(containing)) {
-                    reportWarning.accept("doclet.see.class_or_package_not_accessible",
-                            new Object[] { tagName, utils.getFullyQualifiedName(containing)});
+                    reportWarning.accept("doclet.link.see.reference_not_accessible",
+                            new Object[] { utils.getFullyQualifiedName(containing)});
                 } else {
                     if (!configuration.isDocLintReferenceGroupEnabled()) {
-                        reportWarning.accept("doclet.see.class_or_package_not_found",
-                                new Object[] { tagName, refSignature });
+                        reportWarning.accept("doclet.link.see.reference_not_found",
+                                new Object[] { refSignature });
                     }
                 }
             }
@@ -610,7 +605,7 @@ public class TagletWriterImpl extends TagletWriter {
                 }
             }
 
-            return htmlWriter.getDocLink(HtmlLinkInfo.Kind.SEE_TAG, containing,
+            return htmlWriter.getDocLink(HtmlLinkInfo.Kind.SHOW_PREVIEW, containing,
                     refMem, (labelContent.isEmpty()
                             ? plainOrCode(isLinkPlain, Text.of(refMemName))
                             : labelContent), null, false);
@@ -696,7 +691,6 @@ public class TagletWriterImpl extends TagletWriter {
                                 null,
                                 t,
                                 e,
-                                "link",
                                 false, // TODO: for now
                                 Text.of(sequence.toString()),
                                 (key, args) -> { /* TODO: report diagnostic */ });
@@ -710,17 +704,19 @@ public class TagletWriterImpl extends TagletWriter {
                 code.add(c);
             }
         });
-        String copyText = resources.getText("doclet.Copy_snippet_to_clipboard");
-        String copiedText = resources.getText("doclet.Copied_snippet_to_clipboard");
+        String copyText = resources.getText("doclet.Copy_to_clipboard");
+        String copiedText = resources.getText("doclet.Copied_to_clipboard");
+        String copySnippetText = resources.getText("doclet.Copy_snippet_to_clipboard");
         var snippetContainer = HtmlTree.DIV(HtmlStyle.snippetContainer,
                 new HtmlTree(TagName.BUTTON)
                         .add(HtmlTree.SPAN(Text.of(copyText))
                                 .put(HtmlAttr.DATA_COPIED, copiedText))
                         .add(new HtmlTree(TagName.IMG)
                                 .put(HtmlAttr.SRC, htmlWriter.pathToRoot.resolve(DocPaths.CLIPBOARD_SVG).getPath())
-                                .put(HtmlAttr.ALT, copyText))
+                                .put(HtmlAttr.ALT, copySnippetText))
                         .addStyle(HtmlStyle.copy)
                         .addStyle(HtmlStyle.snippetCopy)
+                        .put(HtmlAttr.ARIA_LABEL, copySnippetText)
                         .put(HtmlAttr.ONCLICK, "copySnippet(this)"));
         return snippetContainer.add(pre.add(code));
     }
@@ -768,7 +764,8 @@ public class TagletWriterImpl extends TagletWriter {
         String specTreeURL = specTree.getURL().getBody();
         List<? extends DocTree> specTreeLabel = specTree.getTitle();
         Content label = htmlWriter.commentTagsToContent(holder, specTreeLabel, isFirstSentence);
-        return getExternalSpecContent(holder, specTree, specTreeURL, textOf(specTreeLabel), label);
+        return getExternalSpecContent(holder, specTree, specTreeURL,
+                textOf(specTreeLabel).replaceAll("\\s+", " "), label);
     }
 
     Content getExternalSpecContent(Element holder, DocTree docTree, String url, String searchText, Content title) {
@@ -816,16 +813,15 @@ public class TagletWriterImpl extends TagletWriter {
         Element exception = ch.getException(throwsTag);
         Content excName;
         if (substituteType != null) {
-            excName = htmlWriter.getLink(new HtmlLinkInfo(configuration, HtmlLinkInfo.Kind.MEMBER,
+            excName = htmlWriter.getLink(new HtmlLinkInfo(configuration, HtmlLinkInfo.Kind.PLAIN,
                    substituteType));
         } else if (exception == null) {
             excName = Text.of(throwsTag.getExceptionName().toString());
         } else if (exception.asType() == null) {
             excName = Text.of(utils.getFullyQualifiedName(exception));
         } else {
-            HtmlLinkInfo link = new HtmlLinkInfo(configuration, HtmlLinkInfo.Kind.MEMBER,
+            HtmlLinkInfo link = new HtmlLinkInfo(configuration, HtmlLinkInfo.Kind.PLAIN,
                                                  exception.asType());
-            link.excludeTypeBounds = true;
             excName = htmlWriter.getLink(link);
         }
         body.add(HtmlTree.CODE(excName));
@@ -840,8 +836,7 @@ public class TagletWriterImpl extends TagletWriter {
 
     @Override
     public Content throwsTagOutput(TypeMirror throwsType, Optional<Content> content) {
-        var linkInfo = new HtmlLinkInfo(configuration, HtmlLinkInfo.Kind.MEMBER, throwsType);
-        linkInfo.excludeTypeBounds = true;
+        var linkInfo = new HtmlLinkInfo(configuration, HtmlLinkInfo.Kind.PLAIN, throwsType);
         var link = htmlWriter.getLink(linkInfo);
         var concat = new ContentBuilder(HtmlTree.CODE(link));
         if (content.isPresent()) {
@@ -854,7 +849,7 @@ public class TagletWriterImpl extends TagletWriter {
     @Override
     public Content valueTagOutput(VariableElement field, String constantVal, boolean includeLink) {
         return includeLink
-                ? htmlWriter.getDocLink(HtmlLinkInfo.Kind.VALUE_TAG, field, constantVal)
+                ? htmlWriter.getDocLink(HtmlLinkInfo.Kind.LINK_TYPE_PARAMS_AND_BOUNDS, field, constantVal)
                 : Text.of(constantVal);
     }
 
@@ -913,56 +908,7 @@ public class TagletWriterImpl extends TagletWriter {
             HtmlId id = HtmlIds.forText(tagText, htmlWriter.indexAnchorTable);
             result = HtmlTree.SPAN(id, HtmlStyle.searchTagResult, tagContent);
             if (options.createIndex() && !tagText.isEmpty()) {
-                String holder = new SimpleElementVisitor14<String, Void>() {
-
-                    @Override
-                    public String visitModule(ModuleElement e, Void p) {
-                        return resources.getText("doclet.module")
-                                + " " + utils.getFullyQualifiedName(e);
-                    }
-
-                    @Override
-                    public String visitPackage(PackageElement e, Void p) {
-                        return resources.getText("doclet.package")
-                                + " " + utils.getFullyQualifiedName(e);
-                    }
-
-                    @Override
-                    public String visitType(TypeElement e, Void p) {
-                        return utils.getTypeElementKindName(e, true)
-                                + " " + utils.getFullyQualifiedName(e);
-                    }
-
-                    @Override
-                    public String visitExecutable(ExecutableElement e, Void p) {
-                        return utils.getFullyQualifiedName(utils.getEnclosingTypeElement(e))
-                                + "." + utils.getSimpleName(e)
-                                + utils.flatSignature(e, htmlWriter.getCurrentPageElement());
-                    }
-
-                    @Override
-                    public String visitVariable(VariableElement e, Void p) {
-                        return utils.getFullyQualifiedName(utils.getEnclosingTypeElement(e))
-                                + "." + utils.getSimpleName(e);
-                    }
-
-                    @Override
-                    public String visitUnknown(Element e, Void p) {
-                        if (e instanceof DocletElement de) {
-                            return switch (de.getSubKind()) {
-                                case OVERVIEW -> resources.getText("doclet.Overview");
-                                case DOCFILE -> getHolderName(de);
-                            };
-                        } else {
-                            return super.visitUnknown(e, p);
-                        }
-                    }
-
-                    @Override
-                    protected String defaultAction(Element e, Void p) {
-                        return utils.getFullyQualifiedName(e);
-                    }
-                }.visit(element);
+                String holder = getHolderName(element);
                 IndexItem item = IndexItem.of(element, tree, tagText, holder, desc,
                         new DocLink(htmlWriter.path, id.name()));
                 configuration.mainIndex.add(item);
@@ -971,6 +917,59 @@ public class TagletWriterImpl extends TagletWriter {
         return result;
     }
 
+    String getHolderName(Element element) {
+        return new SimpleElementVisitor14<String, Void>() {
+
+            @Override
+            public String visitModule(ModuleElement e, Void p) {
+                return resources.getText("doclet.module")
+                        + " " + utils.getFullyQualifiedName(e);
+            }
+
+            @Override
+            public String visitPackage(PackageElement e, Void p) {
+                return resources.getText("doclet.package")
+                        + " " + utils.getFullyQualifiedName(e);
+            }
+
+            @Override
+            public String visitType(TypeElement e, Void p) {
+                return utils.getTypeElementKindName(e, true)
+                        + " " + utils.getFullyQualifiedName(e);
+            }
+
+            @Override
+            public String visitExecutable(ExecutableElement e, Void p) {
+                return utils.getFullyQualifiedName(utils.getEnclosingTypeElement(e))
+                        + "." + utils.getSimpleName(e)
+                        + utils.flatSignature(e, htmlWriter.getCurrentPageElement());
+            }
+
+            @Override
+            public String visitVariable(VariableElement e, Void p) {
+                return utils.getFullyQualifiedName(utils.getEnclosingTypeElement(e))
+                        + "." + utils.getSimpleName(e);
+            }
+
+            @Override
+            public String visitUnknown(Element e, Void p) {
+                if (e instanceof DocletElement de) {
+                    return switch (de.getSubKind()) {
+                        case OVERVIEW -> resources.getText("doclet.Overview");
+                        case DOCFILE -> getHolderName(de);
+                    };
+                } else {
+                    return super.visitUnknown(e, p);
+                }
+            }
+
+            @Override
+            protected String defaultAction(Element e, Void p) {
+                return utils.getFullyQualifiedName(e);
+            }
+        }.visit(element);
+    }
+
     private String getHolderName(DocletElement de) {
         PackageElement pe = de.getPackageElement();
         if (pe.isUnnamed()) {
