@@ -36,6 +36,7 @@ import sun.jvm.hotspot.gc.parallel.ParallelScavengeHeap;
 import sun.jvm.hotspot.gc.serial.SerialHeap;
 import sun.jvm.hotspot.gc.shared.CollectedHeap;
 import sun.jvm.hotspot.gc.shenandoah.ShenandoahHeap;
+import sun.jvm.hotspot.gc.x.XCollectedHeap;
 import sun.jvm.hotspot.gc.z.ZCollectedHeap;
 import sun.jvm.hotspot.oops.Oop;
 import sun.jvm.hotspot.runtime.BasicType;
@@ -51,8 +52,6 @@ import sun.jvm.hotspot.types.TypeDataBase;
 public class Universe {
   private static AddressField collectedHeapField;
   private static VirtualConstructor heapConstructor;
-  private static sun.jvm.hotspot.types.OopField mainThreadGroupField;
-  private static sun.jvm.hotspot.types.OopField systemThreadGroupField;
 
   static {
     VM.registerVMInitializedObserver(new Observer() {
@@ -88,12 +87,10 @@ public class Universe {
     addHeapTypeIfInDB(db, ParallelScavengeHeap.class);
     addHeapTypeIfInDB(db, G1CollectedHeap.class);
     addHeapTypeIfInDB(db, EpsilonHeap.class);
+    addHeapTypeIfInDB(db, XCollectedHeap.class);
     addHeapTypeIfInDB(db, ZCollectedHeap.class);
     addHeapTypeIfInDB(db, ShenandoahHeap.class);
 
-    mainThreadGroupField   = type.getOopField("_main_thread_group");
-    systemThreadGroupField = type.getOopField("_system_thread_group");
-
     UniverseExt.initialize(heapConstructor);
   }
 
@@ -114,19 +111,6 @@ public class Universe {
     return heap().isInReserved(p);
   }
 
-  private Oop newOop(OopHandle handle) {
-    return VM.getVM().getObjectHeap().newOop(handle);
-  }
-
-  public Oop mainThreadGroup() {
-    return newOop(mainThreadGroupField.getValue());
-  }
-
-  public Oop systemThreadGroup() {
-    return newOop(systemThreadGroupField.getValue());
-  }
-
-
   public void print() { printOn(System.out); }
   public void printOn(PrintStream tty) {
     heap().printOn(tty);
