@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -155,6 +151,7 @@ public class CurrencyNames_ru extends OpenListResourceBundle {
             { "MNT", "MNT" },
             { "MOP", "MOP" },
             { "MRO", "MRO" },
+            { "MRU", "MRU" },
             { "MUR", "MUR" },
             { "MVR", "MVR" },
             { "MWK", "MWK" },
@@ -209,6 +206,7 @@ public class CurrencyNames_ru extends OpenListResourceBundle {
             { "UYU", "UYU" },
             { "UZS", "UZS" },
             { "VEF", "VEF" },
+            { "VES", "VES" },
             { "VUV", "VUV" },
             { "WST", "WST" },
             { "XXX", "XXXX" },
@@ -228,7 +226,7 @@ public class CurrencyNames_ru extends OpenListResourceBundle {
             { "aor", "\u0410\u043d\u0433\u043e\u043b\u044c\u0441\u043a\u0430\u044f \u043a\u0432\u0430\u043d\u0437\u0430 \u0440\u0435\u044e\u0441\u0442\u0430\u0434\u043e (1995\u20131999)" },
             { "ara", "\u0410\u0440\u0433\u0435\u043d\u0442\u0438\u043d\u0441\u043a\u0438\u0439 \u0430\u0443\u0441\u0442\u0440\u0430\u043b" },
             { "arp", "\u0410\u0440\u0433\u0435\u043d\u0442\u0438\u043d\u0441\u043a\u043e\u0435 \u043f\u0435\u0441\u043e (1983\u20131985)" },
-            { "ars", "\u0430\u0440\u0433\u0435\u043d\u0442\u0438\u043d\u0441\u043a\u043e\u0435 \u043f\u0435\u0441\u043e" },
+            { "ars", "\u0430\u0440\u0433\u0435\u043d\u0442\u0438\u043d\u0441\u043a\u0438\u0439 \u043f\u0435\u0441\u043e" },
             { "ats", "\u0410\u0432\u0441\u0442\u0440\u0438\u0439\u0441\u043a\u0438\u0439 \u0448\u0438\u043b\u043b\u0438\u043d\u0433" },
             { "aud", "\u0430\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u0439\u0441\u043a\u0438\u0439 \u0434\u043e\u043b\u043b\u0430\u0440" },
             { "awg", "\u0430\u0440\u0443\u0431\u0430\u043d\u0441\u043a\u0438\u0439 \u0444\u043b\u043e\u0440\u0438\u043d" },
@@ -270,16 +268,16 @@ public class CurrencyNames_ru extends OpenListResourceBundle {
             { "chf", "\u0448\u0432\u0435\u0439\u0446\u0430\u0440\u0441\u043a\u0438\u0439 \u0444\u0440\u0430\u043d\u043a" },
             { "chw", "WIR \u0444\u0440\u0430\u043d\u043a" },
             { "clf", "\u0423\u0441\u043b\u043e\u0432\u043d\u0430\u044f \u0440\u0430\u0441\u0447\u0435\u0442\u043d\u0430\u044f \u0435\u0434\u0438\u043d\u0438\u0446\u0430 \u0427\u0438\u043b\u0438" },
-            { "clp", "\u0447\u0438\u043b\u0438\u0439\u0441\u043a\u043e\u0435 \u043f\u0435\u0441\u043e" },
+            { "clp", "\u0447\u0438\u043b\u0438\u0439\u0441\u043a\u0438\u0439 \u043f\u0435\u0441\u043e" },
             { "cnh", "\u043a\u0438\u0442\u0430\u0439\u0441\u043a\u0438\u0439 \u043e\u0444\u0448\u043e\u0440\u043d\u044b\u0439 \u044e\u0430\u043d\u044c" },
             { "cny", "\u043a\u0438\u0442\u0430\u0439\u0441\u043a\u0438\u0439 \u044e\u0430\u043d\u044c" },
-            { "cop", "\u043a\u043e\u043b\u0443\u043c\u0431\u0438\u0439\u0441\u043a\u043e\u0435 \u043f\u0435\u0441\u043e" },
+            { "cop", "\u043a\u043e\u043b\u0443\u043c\u0431\u0438\u0439\u0441\u043a\u0438\u0439 \u043f\u0435\u0441\u043e" },
             { "cou", "\u0415\u0434\u0438\u043d\u0438\u0446\u0430 \u0440\u0435\u0430\u043b\u044c\u043d\u043e\u0439 \u0441\u0442\u043e\u0438\u043c\u043e\u0441\u0442\u0438 \u041a\u043e\u043b\u0443\u043c\u0431\u0438\u0438" },
             { "crc", "\u043a\u043e\u0441\u0442\u0430\u0440\u0438\u043a\u0430\u043d\u0441\u043a\u0438\u0439 \u043a\u043e\u043b\u043e\u043d" },
             { "csd", "\u0421\u0442\u0430\u0440\u044b\u0439 \u0421\u0435\u0440\u0431\u0441\u043a\u0438\u0439 \u0434\u0438\u043d\u0430\u0440" },
             { "csk", "\u0427\u0435\u0445\u043e\u0441\u043b\u043e\u0432\u0430\u0446\u043a\u0430\u044f \u0442\u0432\u0435\u0440\u0434\u0430\u044f \u043a\u0440\u043e\u043d\u0430" },
-            { "cuc", "\u043a\u0443\u0431\u0438\u043d\u0441\u043a\u043e\u0435 \u043a\u043e\u043d\u0432\u0435\u0440\u0442\u0438\u0440\u0443\u0435\u043c\u043e\u0435 \u043f\u0435\u0441\u043e" },
-            { "cup", "\u043a\u0443\u0431\u0438\u043d\u0441\u043a\u043e\u0435 \u043f\u0435\u0441\u043e" },
+            { "cuc", "\u043a\u0443\u0431\u0438\u043d\u0441\u043a\u0438\u0439 \u043a\u043e\u043d\u0432\u0435\u0440\u0442\u0438\u0440\u0443\u0435\u043c\u044b\u0439 \u043f\u0435\u0441\u043e" },
+            { "cup", "\u043a\u0443\u0431\u0438\u043d\u0441\u043a\u0438\u0439 \u043f\u0435\u0441\u043e" },
             { "cve", "\u044d\u0441\u043a\u0443\u0434\u043e \u041a\u0430\u0431\u043e-\u0412\u0435\u0440\u0434\u0435" },
             { "cyp", "\u041a\u0438\u043f\u0440\u0441\u043a\u0438\u0439 \u0444\u0443\u043d\u0442" },
             { "czk", "\u0447\u0435\u0448\u0441\u043a\u0430\u044f \u043a\u0440\u043e\u043d\u0430" },
@@ -287,7 +285,7 @@ public class CurrencyNames_ru extends OpenListResourceBundle {
             { "dem", "\u041d\u0435\u043c\u0435\u0446\u043a\u0430\u044f \u043c\u0430\u0440\u043a\u0430" },
             { "djf", "\u0444\u0440\u0430\u043d\u043a \u0414\u0436\u0438\u0431\u0443\u0442\u0438" },
             { "dkk", "\u0434\u0430\u0442\u0441\u043a\u0430\u044f \u043a\u0440\u043e\u043d\u0430" },
-            { "dop", "\u0434\u043e\u043c\u0438\u043d\u0438\u043a\u0430\u043d\u0441\u043a\u043e\u0435 \u043f\u0435\u0441\u043e" },
+            { "dop", "\u0434\u043e\u043c\u0438\u043d\u0438\u043a\u0430\u043d\u0441\u043a\u0438\u0439 \u043f\u0435\u0441\u043e" },
             { "dzd", "\u0430\u043b\u0436\u0438\u0440\u0441\u043a\u0438\u0439 \u0434\u0438\u043d\u0430\u0440" },
             { "ecs", "\u042d\u043a\u0432\u0430\u0434\u043e\u0440\u0441\u043a\u0438\u0439 \u0441\u0443\u043a\u0440\u0435" },
             { "ecv", "\u041f\u043e\u0441\u0442\u043e\u044f\u043d\u043d\u0430\u044f \u0435\u0434\u0438\u043d\u0438\u0446\u0430 \u0441\u0442\u043e\u0438\u043c\u043e\u0441\u0442\u0438 \u042d\u043a\u0432\u0430\u0434\u043e\u0440\u0430" },
@@ -339,17 +337,17 @@ public class CurrencyNames_ru extends OpenListResourceBundle {
             { "kes", "\u043a\u0435\u043d\u0438\u0439\u0441\u043a\u0438\u0439 \u0448\u0438\u043b\u043b\u0438\u043d\u0433" },
             { "kgs", "\u043a\u0438\u0440\u0433\u0438\u0437\u0441\u043a\u0438\u0439 \u0441\u043e\u043c" },
             { "khr", "\u043a\u0430\u043c\u0431\u043e\u0434\u0436\u0438\u0439\u0441\u043a\u0438\u0439 \u0440\u0438\u0435\u043b\u044c" },
-            { "kmf", "\u0444\u0440\u0430\u043d\u043a \u041a\u043e\u043c\u043e\u0440\u0441\u043a\u0438\u0445 \u043e\u0441\u0442\u0440\u043e\u0432\u043e\u0432" },
+            { "kmf", "\u043a\u043e\u043c\u043e\u0440\u0441\u043a\u0438\u0439 \u0444\u0440\u0430\u043d\u043a" },
             { "kpw", "\u0441\u0435\u0432\u0435\u0440\u043e\u043a\u043e\u0440\u0435\u0439\u0441\u043a\u0430\u044f \u0432\u043e\u043d\u0430" },
             { "krw", "\u044e\u0436\u043d\u043e\u043a\u043e\u0440\u0435\u0439\u0441\u043a\u0430\u044f \u0432\u043e\u043d\u0430" },
             { "kwd", "\u043a\u0443\u0432\u0435\u0439\u0442\u0441\u043a\u0438\u0439 \u0434\u0438\u043d\u0430\u0440" },
-            { "kyd", "\u0434\u043e\u043b\u043b\u0430\u0440 \u041a\u0430\u0439\u043c\u0430\u043d\u043e\u0432\u044b\u0445 \u043e\u0441\u0442\u0440\u043e\u0432\u043e\u0432" },
+            { "kyd", "\u0434\u043e\u043b\u043b\u0430\u0440 \u041e\u0441\u0442\u0440\u043e\u0432\u043e\u0432 \u041a\u0430\u0439\u043c\u0430\u043d" },
             { "kzt", "\u043a\u0430\u0437\u0430\u0445\u0441\u043a\u0438\u0439 \u0442\u0435\u043d\u0433\u0435" },
             { "lak", "\u043b\u0430\u043e\u0441\u0441\u043a\u0438\u0439 \u043a\u0438\u043f" },
             { "lbp", "\u043b\u0438\u0432\u0430\u043d\u0441\u043a\u0438\u0439 \u0444\u0443\u043d\u0442" },
             { "lkr", "\u0448\u0440\u0438-\u043b\u0430\u043d\u043a\u0438\u0439\u0441\u043a\u0430\u044f \u0440\u0443\u043f\u0438\u044f" },
             { "lrd", "\u043b\u0438\u0431\u0435\u0440\u0438\u0439\u0441\u043a\u0438\u0439 \u0434\u043e\u043b\u043b\u0430\u0440" },
-            { "lsl", "\u041b\u043e\u0442\u0438" },
+            { "lsl", "\u043b\u043e\u0442\u0438" },
             { "ltl", "\u041b\u0438\u0442\u043e\u0432\u0441\u043a\u0438\u0439 \u043b\u0438\u0442" },
             { "ltt", "\u041b\u0438\u0442\u043e\u0432\u0441\u043a\u0438\u0439 \u0442\u0430\u043b\u043e\u043d" },
             { "luc", "\u041a\u043e\u043d\u0432\u0435\u0440\u0442\u0438\u0440\u0443\u0435\u043c\u044b\u0439 \u0444\u0440\u0430\u043d\u043a \u041b\u044e\u043a\u0441\u0435\u043c\u0431\u0443\u0440\u0433\u0430" },
@@ -375,7 +373,7 @@ public class CurrencyNames_ru extends OpenListResourceBundle {
             { "mur", "\u043c\u0430\u0432\u0440\u0438\u043a\u0438\u0439\u0441\u043a\u0430\u044f \u0440\u0443\u043f\u0438\u044f" },
             { "mvr", "\u043c\u0430\u043b\u044c\u0434\u0438\u0432\u0441\u043a\u0430\u044f \u0440\u0443\u0444\u0438\u044f" },
             { "mwk", "\u043c\u0430\u043b\u0430\u0432\u0438\u0439\u0441\u043a\u0430\u044f \u043a\u0432\u0430\u0447\u0430" },
-            { "mxn", "\u043c\u0435\u043a\u0441\u0438\u043a\u0430\u043d\u0441\u043a\u043e\u0435 \u043f\u0435\u0441\u043e" },
+            { "mxn", "\u043c\u0435\u043a\u0441\u0438\u043a\u0430\u043d\u0441\u043a\u0438\u0439 \u043f\u0435\u0441\u043e" },
             { "mxp", "\u041c\u0435\u043a\u0441\u0438\u043a\u0430\u043d\u0441\u043a\u043e\u0435 \u0441\u0435\u0440\u0435\u0431\u0440\u044f\u043d\u043e\u0435 \u043f\u0435\u0441\u043e (1861\u20131992)" },
             { "mxv", "\u041c\u0435\u043a\u0441\u0438\u043a\u0430\u043d\u0441\u043a\u0430\u044f \u043f\u0435\u0440\u0435\u0441\u0447\u0435\u0442\u043d\u0430\u044f \u0435\u0434\u0438\u043d\u0438\u0446\u0430 (UDI)" },
             { "myr", "\u043c\u0430\u043b\u0430\u0439\u0437\u0438\u0439\u0441\u043a\u0438\u0439 \u0440\u0438\u043d\u0433\u0433\u0438\u0442" },
@@ -396,7 +394,7 @@ public class CurrencyNames_ru extends OpenListResourceBundle {
             { "pen", "\u043f\u0435\u0440\u0443\u0430\u043d\u0441\u043a\u0438\u0439 \u0441\u043e\u043b\u044c" },
             { "pes", "\u041f\u0435\u0440\u0443\u0430\u043d\u0441\u043a\u0438\u0439 \u0441\u043e\u043b\u044c (1863\u20131965)" },
             { "pgk", "\u043a\u0438\u043d\u0430 \u041f\u0430\u043f\u0443\u0430 \u2013 \u041d\u043e\u0432\u043e\u0439 \u0413\u0432\u0438\u043d\u0435\u0438" },
-            { "php", "\u0444\u0438\u043b\u0438\u043f\u043f\u0438\u043d\u0441\u043a\u043e\u0435 \u043f\u0435\u0441\u043e" },
+            { "php", "\u0444\u0438\u043b\u0438\u043f\u043f\u0438\u043d\u0441\u043a\u0438\u0439 \u043f\u0435\u0441\u043e" },
             { "pkr", "\u043f\u0430\u043a\u0438\u0441\u0442\u0430\u043d\u0441\u043a\u0430\u044f \u0440\u0443\u043f\u0438\u044f" },
             { "pln", "\u043f\u043e\u043b\u044c\u0441\u043a\u0438\u0439 \u0437\u043b\u043e\u0442\u044b\u0439" },
             { "plz", "\u0417\u043b\u043e\u0442\u044b\u0439" },
@@ -411,7 +409,7 @@ public class CurrencyNames_ru extends OpenListResourceBundle {
             { "rur", "\u0420\u043e\u0441\u0441\u0438\u0439\u0441\u043a\u0438\u0439 \u0440\u0443\u0431\u043b\u044c (1991\u20131998)" },
             { "rwf", "\u0444\u0440\u0430\u043d\u043a \u0420\u0443\u0430\u043d\u0434\u044b" },
             { "sar", "\u0441\u0430\u0443\u0434\u043e\u0432\u0441\u043a\u0438\u0439 \u0440\u0438\u044f\u043b" },
-            { "sbd", "\u0434\u043e\u043b\u043b\u0430\u0440 \u0421\u043e\u043b\u043e\u043c\u043e\u043d\u043e\u0432\u044b\u0445 \u043e\u0441\u0442\u0440\u043e\u0432\u043e\u0432" },
+            { "sbd", "\u0434\u043e\u043b\u043b\u0430\u0440 \u0421\u043e\u043b\u043e\u043c\u043e\u043d\u043e\u0432\u044b\u0445 \u041e\u0441\u0442\u0440\u043e\u0432\u043e\u0432" },
             { "scr", "\u0441\u0435\u0439\u0448\u0435\u043b\u044c\u0441\u043a\u0430\u044f \u0440\u0443\u043f\u0438\u044f" },
             { "sdd", "\u0421\u0443\u0434\u0430\u043d\u0441\u043a\u0438\u0439 \u0434\u0438\u043d\u0430\u0440" },
             { "sdg", "\u0441\u0443\u0434\u0430\u043d\u0441\u043a\u0438\u0439 \u0444\u0443\u043d\u0442" },
@@ -454,10 +452,11 @@ public class CurrencyNames_ru extends OpenListResourceBundle {
             { "uss", "\u0414\u043e\u043b\u043b\u0430\u0440 \u0421\u0428\u0410 \u0442\u0435\u043a\u0443\u0449\u0435\u0433\u043e \u0434\u043d\u044f" },
             { "uyi", "\u0423\u0440\u0443\u0433\u0432\u0430\u0439\u0441\u043a\u0438\u0439 \u043f\u0435\u0441\u043e (\u0438\u043d\u0434\u0435\u043a\u0441 \u0438\u043d\u0444\u043b\u044f\u0446\u0438\u0438)" },
             { "uyp", "\u0423\u0440\u0443\u0433\u0432\u0430\u0439\u0441\u043a\u043e\u0435 \u0441\u0442\u0430\u0440\u043e\u0435 \u043f\u0435\u0441\u043e (1975\u20131993)" },
-            { "uyu", "\u0443\u0440\u0443\u0433\u0432\u0430\u0439\u0441\u043a\u043e\u0435 \u043f\u0435\u0441\u043e" },
+            { "uyu", "\u0443\u0440\u0443\u0433\u0432\u0430\u0439\u0441\u043a\u0438\u0439 \u043f\u0435\u0441\u043e" },
             { "uzs", "\u0443\u0437\u0431\u0435\u043a\u0441\u043a\u0438\u0439 \u0441\u0443\u043c" },
             { "veb", "\u0412\u0435\u043d\u0435\u0441\u0443\u044d\u043b\u044c\u0441\u043a\u0438\u0439 \u0431\u043e\u043b\u0438\u0432\u0430\u0440 (1871\u20132008)" },
-            { "vef", "\u0432\u0435\u043d\u0435\u0441\u0443\u044d\u043b\u044c\u0441\u043a\u0438\u0439 \u0431\u043e\u043b\u0438\u0432\u0430\u0440" },
+            { "vef", "\u0432\u0435\u043d\u0435\u0441\u0443\u044d\u043b\u044c\u0441\u043a\u0438\u0439 \u0431\u043e\u043b\u0438\u0432\u0430\u0440 (2008\u20132018)" },
+            { "ves", "\u0432\u0435\u043d\u0435\u0441\u0443\u044d\u043b\u044c\u0441\u043a\u0438\u0439 \u0431\u043e\u043b\u0438\u0432\u0430\u0440" },
             { "vnd", "\u0432\u044c\u0435\u0442\u043d\u0430\u043c\u0441\u043a\u0438\u0439 \u0434\u043e\u043d\u0433" },
             { "vuv", "\u0432\u0430\u0442\u0443 \u0412\u0430\u043d\u0443\u0430\u0442\u0443" },
             { "wst", "\u0441\u0430\u043c\u043e\u0430\u043d\u0441\u043a\u0430\u044f \u0442\u0430\u043b\u0430" },
