@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -70,6 +66,11 @@ import sun.util.resources.OpenListResourceBundle;
 public class LocaleNames_sk extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String metaValue_ccp = "\u010dakma";
+        final String metaValue_bm = "bambar\u010dina";
+        final String metaValue_su = "sund\u010dina";
+        final String metaValue_syr = "s\u00fdr\u010dina";
+        final String metaValue_vai = "vai";
         final Object[][] data = new Object[][] {
             { "001", "svet" },
             { "002", "Afrika" },
@@ -381,7 +382,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "be", "bieloru\u0161tina" },
             { "bg", "bulhar\u010dina" },
             { "bi", "bislama" },
-            { "bm", "bambar\u010dina" },
+            { "bm", metaValue_bm },
             { "bn", "beng\u00e1l\u010dina" },
             { "bo", "tibet\u010dina" },
             { "br", "bret\u00f3n\u010dina" },
@@ -517,7 +518,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "sr", "srb\u010dina" },
             { "ss", "svazij\u010dina" },
             { "st", "soth\u010dina (ju\u017en\u00e1)" },
-            { "su", "sund\u010dina" },
+            { "su", metaValue_su },
             { "sv", "\u0161v\u00e9d\u010dina" },
             { "sw", "swahil\u010dina" },
             { "ta", "tamil\u010dina" },
@@ -560,6 +561,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "ale", "aleut\u010dina" },
             { "alt", "ju\u017en\u00e1 altaj\u010dina" },
             { "ang", "star\u00e1 angli\u010dtina" },
+            { "ann", "obolo" },
             { "anp", "angika" },
             { "arc", "aramej\u010dina" },
             { "arn", "mapudungun" },
@@ -568,6 +570,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "arw", "arawa\u010dtina" },
             { "asa", "asu" },
             { "ast", "ast\u00far\u010dina" },
+            { "atj", "atikamekw\u010dina" },
             { "awa", "awadhi" },
             { "bal", "bal\u00fa\u010dtina" },
             { "ban", "balij\u010dina" },
@@ -596,7 +599,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "car", "karib\u010dina" },
             { "cay", "kajug\u010dina" },
             { "cch", "atsam" },
-            { "ccp", "\u010dakma" },
+            { "ccp", metaValue_ccp },
             { "ceb", "cebu\u00e1n\u010dina" },
             { "cgg", "kiga" },
             { "chb", "\u010dib\u010da" },
@@ -609,10 +612,18 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "chr", "\u010derok\u00ed" },
             { "chy", "\u010dejen\u010dina" },
             { "ckb", "kurd\u010dina (sor\u00e1n\u00ed)" },
+            { "clc", "chilcotin" },
             { "cop", "kopt\u010dina" },
+            { "crg", "michif" },
             { "crh", "krymsk\u00e1 tat\u00e1r\u010dina" },
+            { "crj", "cree (juhov\u00fdchod)" },
+            { "crk", "plains cree" },
+            { "crl", "northern east cree" },
+            { "crm", "moose cree" },
+            { "crr", "karol\u00ednska algonk\u010dina" },
             { "crs", "seychelsk\u00e1 kreol\u010dina" },
             { "csb", "ka\u0161ub\u010dina" },
+            { "csw", "swampy cree" },
             { "dak", "dakot\u010dina" },
             { "dar", "dargin\u010dina" },
             { "dav", "taita" },
@@ -663,13 +674,16 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "gwi", "ku\u010din\u010dina" },
             { "hai", "haida" },
             { "haw", "havaj\u010dina" },
+            { "hax", "haida (juh)" },
             { "hil", "hiligajnon\u010dina" },
             { "hit", "chetit\u010dina" },
             { "hmn", "hmong\u010dina" },
             { "hsb", "hornolu\u017eick\u00e1 srb\u010dina" },
             { "hup", "hup\u010dina" },
+            { "hur", "halkomelem" },
             { "iba", "iban\u010dina" },
             { "ibb", "ibibio" },
+            { "ikt", "inuktitut (z\u00e1padn\u00e1 Kanada)" },
             { "ilo", "ilok\u00e1n\u010dina" },
             { "inh", "ingu\u0161tina" },
             { "jbo", "lojban" },
@@ -689,6 +703,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "kde", "makonde" },
             { "kea", "kapverd\u010dina" },
             { "kfo", "koro" },
+            { "kgp", "kaingang" },
             { "kha", "khasij\u010dina" },
             { "kho", "chotan\u010dina" },
             { "khq", "z\u00e1padn\u00e1 songhaj\u010dina" },
@@ -707,16 +722,19 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "ksh", "kol\u00edn\u010dina" },
             { "kum", "kumy\u010dtina" },
             { "kut", "kutenaj\u010dina" },
+            { "kwk", "kwak\u02bcwala" },
             { "lad", "\u017eidovsk\u00e1 \u0161paniel\u010dina" },
             { "lag", "langi" },
             { "lah", "lahand\u010dina" },
             { "lam", "lamba" },
             { "lez", "lezgin\u010dina" },
+            { "lil", "lillooet" },
             { "lkt", "lakot\u010dina" },
             { "lol", "mongo" },
             { "lou", "kreol\u010dina (Louisiana)" },
             { "loz", "lozi" },
             { "lrc", "severn\u00e9 luri" },
+            { "lsm", "saamia" },
             { "lua", "lub\u010dina (lulu\u00e1nska)" },
             { "lui", "luise\u0148o" },
             { "lun", "lunda" },
@@ -743,6 +761,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "min", "minangkabau\u010dina" },
             { "mnc", "mand\u017eu\u0161tina" },
             { "mni", "man\u00edpur\u010dina" },
+            { "moe", "innu-aimun\u010dina" },
             { "moh", "mohawk\u010dina" },
             { "mos", "mossi" },
             { "mua", "mundang" },
@@ -771,6 +790,11 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "nyn", "\u0148ankole" },
             { "nyo", "\u0148oro" },
             { "nzi", "nzima" },
+            { "ojb", "northwestern ojibwa" },
+            { "ojc", "centr\u00e1lna od\u017eibvej\u010dina" },
+            { "ojs", "oji-cree" },
+            { "ojw", "ojibwa (z\u00e1pad)" },
+            { "oka", "okanagan" },
             { "osa", "osed\u017e\u0161tina" },
             { "ota", "osmansk\u00e1 ture\u010dtina" },
             { "pag", "pangasinan\u010dina" },
@@ -781,13 +805,16 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "pcm", "nigerijsk\u00fd pid\u017ein" },
             { "peo", "star\u00e1 perz\u0161tina" },
             { "phn", "feni\u010dtina" },
+            { "pis", "pid\u017ein" },
             { "pon", "pohnpei\u0161tina" },
+            { "pqm", "maliseet-passamaquoddy" },
             { "prg", "pru\u0161tina" },
             { "pro", "star\u00e1 okcit\u00e1n\u010dina" },
             { "quc", "quich\u00e9" },
             { "raj", "rad\u017eastan\u010dina" },
             { "rap", "rapanuj\u010dina" },
             { "rar", "rarotongsk\u00e1 maorij\u010dina" },
+            { "rhg", "rohing\u010dina" },
             { "rof", "rombo" },
             { "rom", "r\u00f3m\u010dina" },
             { "rup", "arumun\u010dina" },
@@ -812,6 +839,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "shn", "\u0161an\u010dina" },
             { "shu", "\u010dadsk\u00e1 arab\u010dina" },
             { "sid", "sidamo" },
+            { "slh", "lushootseed (juh)" },
             { "sma", "saam\u010dina (ju\u017en\u00e1)" },
             { "smj", "saam\u010dina (lulsk\u00e1)" },
             { "smn", "saam\u010dina (inarijsk\u00e1)" },
@@ -821,16 +849,20 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "srn", "surinam\u010dina" },
             { "srr", "serer\u010dina" },
             { "ssy", "saho" },
+            { "str", "straits salish" },
             { "suk", "sukuma" },
             { "sus", "susu" },
             { "sux", "sumer\u010dina" },
             { "swb", "komor\u010dina" },
             { "syc", "s\u00fdr\u010dina (klasick\u00e1)" },
-            { "syr", "s\u00fdr\u010dina" },
+            { "syr", metaValue_syr },
+            { "tce", "tutchone (juh)" },
             { "tem", "temne" },
             { "teo", "teso" },
             { "ter", "ter\u00eana" },
             { "tet", "tetum\u010dina" },
+            { "tgx", "tagi\u0161" },
+            { "tht", "tahltan" },
             { "tig", "tigrej\u010dina" },
             { "tiv", "tiv" },
             { "tkl", "tokelau\u0161tina" },
@@ -838,19 +870,21 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "tli", "tlingit\u010dina" },
             { "tmh", "tuareg\u010dina" },
             { "tog", "\u0148asa tonga" },
+            { "tok", "toki pona" },
             { "tpi", "novoguinejsk\u00fd pid\u017ein" },
             { "trv", "taroko" },
             { "tsi", "cim\u0161jan\u010dina" },
+            { "ttm", "northern tutchone" },
             { "tum", "tumbuka" },
             { "tvl", "tuval\u010dina" },
             { "twq", "tasawaq" },
             { "tyv", "tuvian\u010dina" },
-            { "tzm", "tuareg\u010dina (stredomarock\u00e1)" },
+            { "tzm", "tamazight (stredomarock\u00fd)" },
             { "udm", "udmurt\u010dina" },
             { "uga", "ugarit\u010dina" },
             { "umb", "umbundu" },
             { "und", "nezn\u00e1my jazyk" },
-            { "vai", "vai" },
+            { "vai", metaValue_vai },
             { "vot", "vod\u010dina" },
             { "vun", "vunjo" },
             { "wae", "walser\u010dina" },
@@ -858,12 +892,14 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "war", "waray" },
             { "was", "washo" },
             { "wbp", "warlpiri" },
+            { "wuu", "\u010d\u00edn\u0161tina (wu)" },
             { "xal", "kalmy\u010dtina" },
             { "xog", "soga" },
             { "yao", "jao" },
             { "yap", "jap\u010dina" },
             { "yav", "jangben" },
             { "ybb", "yemba" },
+            { "yrl", "nheengatu" },
             { "yue", "kanton\u010dina" },
             { "zap", "zapot\u00e9\u010dtina" },
             { "zbl", "syst\u00e9m Bliss" },
@@ -872,12 +908,17 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "zun", "zuni\u0161tina" },
             { "zxx", "bez jazykov\u00e9ho obsahu" },
             { "zza", "zaza" },
+            { "Adlm", "adlam" },
             { "Arab", "arabsk\u00e9" },
+            { "Aran", "nastaliq" },
             { "Armn", "arm\u00e9nske" },
             { "Bali", "balijsk\u00fd" },
             { "Beng", "beng\u00e1lske" },
             { "Bopo", "bopomofo" },
             { "Brai", "braillovo" },
+            { "Cakm", metaValue_ccp },
+            { "Cans", "zjednoten\u00e9 kanadsk\u00e9 domorod\u00e9 slabiky" },
+            { "Cher", "\u010derok\u00e9z\u010dina" },
             { "Cyrl", "cyrilika" },
             { "Deva", "d\u00e9van\u00e1gar\u00ed" },
             { "Egyp", "egyptsk\u00e9 hieroglyfy" },
@@ -909,23 +950,32 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "Maya", "maysk\u00e9 hieroglyfy" },
             { "Mlym", "malaj\u00e1lamske" },
             { "Mong", "mongolsk\u00e9" },
+            { "Mtei", "mejtej majek (manipursk\u00e9)" },
             { "Mymr", "barmsk\u00e9" },
+            { "Nkoo", metaValue_bm },
+            { "Olck", "sant\u00e1lske (ol chiki)" },
             { "Orya", "ur\u00edjske" },
             { "Osma", "osmansk\u00fd" },
+            { "Qaag", "zawgyi" },
+            { "Rohg", "hanifi" },
             { "Runr", "Runov\u00e9 p\u00edsmo" },
             { "Sinh", "sinh\u00e1lske" },
+            { "Sund", metaValue_su },
+            { "Syrc", metaValue_syr },
             { "Taml", "tamilsk\u00e9" },
             { "Telu", "telugsk\u00e9" },
+            { "Tfng", "tifinagh" },
             { "Thaa", "t\u00e1na" },
             { "Thai", "thajsk\u00e9" },
             { "Tibt", "tibetsk\u00e9" },
+            { "Vaii", metaValue_vai },
+            { "Yiii", "yi" },
             { "Zmth", "matematick\u00fd z\u00e1pis" },
             { "Zsye", "emod\u017ei" },
             { "Zsym", "symboly" },
             { "Zxxx", "bez z\u00e1pisu" },
             { "Zyyy", "v\u0161eobecn\u00e9" },
             { "Zzzz", "nezn\u00e1me p\u00edsmo" },
-            { "root", "kore\u0148" },
             { "de_AT", "nem\u010dina (rak\u00faska)" },
             { "de_CH", "nem\u010dina (\u0161vaj\u010diarska spisovn\u00e1)" },
             { "en_AU", "angli\u010dtina (austr\u00e1lska)" },
@@ -934,6 +984,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "en_US", "angli\u010dtina (americk\u00e1)" },
             { "es_ES", "\u0161paniel\u010dina (eur\u00f3pska)" },
             { "es_MX", "\u0161paniel\u010dina (mexick\u00e1)" },
+            { "fa_AF", "dar\u00edj\u010dina" },
             { "fr_CA", "franc\u00faz\u0161tina (kanadsk\u00e1)" },
             { "fr_CH", "franc\u00faz\u0161tina (\u0161vaj\u010diarska)" },
             { "nl_BE", "fl\u00e1m\u010dina" },
@@ -967,6 +1018,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "type.nu.arab", "arabsko-indick\u00e9 \u010d\u00edslice" },
             { "type.nu.armn", "arm\u00e9nske \u010d\u00edslice" },
             { "type.nu.beng", "beng\u00e1lske \u010d\u00edslice" },
+            { "type.nu.cakm", "\u010d\u00edslice chakma" },
             { "type.nu.deva", "\u010d\u00edslice d\u00e9van\u00e1gar\u00ed" },
             { "type.nu.ethi", "eti\u00f3pske \u010d\u00edslice" },
             { "type.nu.geor", "gruz\u00ednske \u010d\u00edslice" },
@@ -976,6 +1028,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "type.nu.hans", "\u010d\u00edslice zjednodu\u0161enej \u010d\u00edn\u0161tiny" },
             { "type.nu.hant", "\u010d\u00edslice tradi\u010dnej \u010d\u00edn\u0161tiny" },
             { "type.nu.hebr", "hebrejsk\u00e9 \u010d\u00edslice" },
+            { "type.nu.java", "j\u00e1vske \u010d\u00edslice" },
             { "type.nu.jpan", "japonsk\u00e9 \u010d\u00edslice" },
             { "type.nu.khmr", "khm\u00e9rske \u010d\u00edslice" },
             { "type.nu.knda", "kannadsk\u00e9 \u010d\u00edslice" },
@@ -983,38 +1036,41 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "type.nu.latn", "arabsk\u00e9 \u010d\u00edslice" },
             { "type.nu.mlym", "malaj\u00e1lamske \u010d\u00edslice" },
             { "type.nu.mong", "Mongolsk\u00e9 \u010d\u00edslice" },
+            { "type.nu.mtei", "\u010d\u00edslice meetei mayek" },
             { "type.nu.mymr", "barmsk\u00e9 \u010d\u00edslice" },
+            { "type.nu.olck", "\u010d\u00edslice ol chiki" },
             { "type.nu.orya", "ur\u00edjske \u010d\u00edslice" },
             { "type.nu.taml", "\u010d\u00edslice tradi\u010dnej tamil\u010diny" },
             { "type.nu.telu", "telugsk\u00e9 \u010d\u00edslice" },
             { "type.nu.thai", "thajsk\u00e9 \u010d\u00edslice" },
             { "type.nu.tibt", "tibetsk\u00e9 \u010d\u00edslice" },
-            { "type.nu.vaii", "Vaisk\u00e9 \u010d\u00edslice" },
+            { "type.nu.vaii", "vaisk\u00e9 \u010d\u00edslice" },
             { "type.ca.dangi", "k\u00f3rejsk\u00fd kalend\u00e1r" },
             { "type.co.ducet", "predvolen\u00e9 zoradenie unicode" },
             { "type.lb.loose", "vo\u013en\u00fd \u0161t\u00fdl koncov riadka" },
             { "type.nu.roman", "r\u00edmske \u010d\u00edslice" },
-            { "type.ca.coptic", "Koptick\u00fd kalend\u00e1r" },
+            { "type.ca.coptic", "koptsk\u00fd kalend\u00e1r" },
             { "type.ca.hebrew", "\u017eidovsk\u00fd kalend\u00e1r" },
             { "type.ca.indian", "Indick\u00fd n\u00e1rodn\u00fd kalend\u00e1r" },
             { "type.co.compat", "predch\u00e1dzaj\u00face zoradenie, kompatibilita" },
-            { "type.co.pinyin", "Triedenie pinyin" },
+            { "type.co.pinyin", "zoradenie pinyin" },
             { "type.co.search", "v\u0161eobecn\u00e9 vyh\u013ead\u00e1vanie" },
-            { "type.co.stroke", "Tiedenie pod\u013ea \u0165ahov" },
-            { "type.co.unihan", "Usporiadanie pod\u013ea znakov radik\u00e1l" },
+            { "type.co.stroke", "zoradenie pod\u013ea \u0165ahov" },
+            { "type.co.unihan", "zoradenie pod\u013ea znakov radik\u00e1l" },
+            { "type.co.zhuyin", "zoradenie zhuyin" },
             { "type.d0.fwidth", "cel\u00e1 \u0161\u00edrka" },
             { "type.d0.hwidth", "polovi\u010dn\u00e1 \u0161\u00edrka" },
             { "type.lb.normal", "be\u017en\u00fd \u0161t\u00fdl koncov riadka" },
             { "type.lb.strict", "presn\u00fd \u0161t\u00fdl koncov riadka" },
             { "type.m0.ungegn", "medzin\u00e1rodn\u00e1 transliter\u00e1cia GEGN" },
             { "type.ms.metric", "metrick\u00e1 s\u00fastava" },
-            { "type.nu.native", "Nat\u00edvne \u010d\u00edslice" },
+            { "type.nu.native", "nat\u00edvne \u010d\u00edslice" },
             { "type.ca.chinese", "\u010d\u00ednsky kalend\u00e1r" },
             { "type.ca.islamic", "islamsk\u00fd kalend\u00e1r" },
             { "type.ca.iso8601", "kalend\u00e1r ISO 8601" },
             { "type.ca.persian", "perzsk\u00fd kalend\u00e1r" },
             { "type.cf.account", "\u00fa\u010dtovn\u00fd form\u00e1t meny" },
-            { "type.co.big5han", "Tradi\u010dn\u00fd \u010d\u00ednsky Big5" },
+            { "type.co.big5han", "tradi\u010dn\u00fd \u010d\u00ednsky Big5" },
             { "type.d0.npinyin", "\u010c\u00edslice" },
             { "type.nu.arabext", "roz\u0161\u00edren\u00e9 arabsko-indick\u00e9 \u010d\u00edslice" },
             { "type.nu.armnlow", "mal\u00e9 arm\u00e9nske \u010d\u00edslice" },
@@ -1029,8 +1085,8 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "type.ca.ethiopic", "eti\u00f3psky kalend\u00e1r" },
             { "type.ca.japanese", "japonsk\u00fd kalend\u00e1r" },
             { "type.cf.standard", "\u0161tandardn\u00fd form\u00e1t meny" },
-            { "type.co.phonetic", "Fonetick\u00e9 radenie" },
-            { "type.co.reformed", "Reformovan\u00e9 usporiadanie" },
+            { "type.co.phonetic", "fonetick\u00e9 zoradenie" },
+            { "type.co.reformed", "reformovan\u00e9 zoradenie" },
             { "type.co.searchjl", "H\u013eada\u0165 pod\u013ea po\u010diato\u010dnej spoluhl\u00e1sky p\u00edsma Hangul" },
             { "type.co.standard", "\u0161tandardn\u00e9 zoradenie" },
             { "type.ms.uksystem", "britsk\u00e1 mern\u00e1 s\u00fastava" },
@@ -1038,14 +1094,14 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "type.nu.fullwide", "\u010d\u00edslice s celou \u0161\u00edrkou" },
             { "type.nu.romanlow", "mal\u00e9 r\u00edmske \u010d\u00edslice" },
             { "type.ca.gregorian", "gregori\u00e1nsky kalend\u00e1r" },
-            { "type.co.gb2312han", "Zjednodu\u0161en\u00fd \u010d\u00ednsky GB2312" },
-            { "type.co.phonebook", "Lexikografick\u00e9 triedenie" },
-            { "type.co.dictionary", "Usporiadanie slovn\u00edka" },
-            { "type.co.traditional", "Tradi\u010dn\u00e9" },
+            { "type.co.gb2312han", "zjednodu\u0161en\u00fd \u010d\u00ednsky GB2312" },
+            { "type.co.phonebook", "lexikografick\u00e9 zoradenie" },
+            { "type.co.dictionary", "slovn\u00edkov\u00e9 zoradenie" },
+            { "type.co.traditional", "tradi\u010dn\u00e9 poradie zoradenia" },
             { "type.nu.traditional", "Tradi\u010dn\u00e9 \u010d\u00edslovky" },
-            { "type.ca.islamic-civil", "Islamsk\u00fd ob\u010diansky kalend\u00e1r" },
+            { "type.ca.islamic-civil", "islamsk\u00fd ob\u010diansky kalend\u00e1r" },
             { "type.ca.islamic-umalqura", "islamsk\u00fd kalend\u00e1r (Umm al-Qura)" },
-            { "type.ca.ethiopic-amete-alem", "Eti\u00f3psky kalend\u00e1r Amete Alem" },
+            { "type.ca.ethiopic-amete-alem", "eti\u00f3psky kalend\u00e1r Amete Alem" },
         };
         return data;
     }
