@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -555,13 +555,16 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "ale", "aleut\u0161\u010dina" },
             { "alt", "ju\u017ena altaj\u0161\u010dina" },
             { "ang", "stara angle\u0161\u010dina" },
+            { "ann", "obolo" },
             { "anp", "angika\u0161\u010dina" },
             { "arc", "aramej\u0161\u010dina" },
             { "arn", "mapudungun\u0161\u010dina" },
             { "arp", "arapa\u0161\u010dina" },
+            { "ars", "nad\u017edska arab\u0161\u010dina" },
             { "arw", "arava\u0161\u010dina" },
             { "asa", "asuj\u0161\u010dina" },
             { "ast", "asturij\u0161\u010dina" },
+            { "atj", "atikamekw\u0161\u010dina" },
             { "awa", "avad\u0161\u010dina" },
             { "bal", "belud\u017eij\u0161\u010dina" },
             { "ban", "balij\u0161\u010dina" },
@@ -581,6 +584,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "byn", "blin\u0161\u010dina" },
             { "cad", "kado\u0161\u010dina" },
             { "car", "karibski jezik" },
+            { "cay", "kaju\u0161\u010dina" },
             { "ccp", "chakma" },
             { "ceb", "sebuan\u0161\u010dina" },
             { "cgg", "\u010digaj\u0161\u010dina" },
@@ -594,10 +598,18 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "chr", "\u010deroke\u0161\u010dina" },
             { "chy", "\u010dejen\u0161\u010dina" },
             { "ckb", "soranska kurd\u0161\u010dina" },
+            { "clc", "\u010dilkotin\u0161\u010dina" },
             { "cop", "kopt\u0161\u010dina" },
+            { "crg", "mi\u010dif\u0161\u010dina" },
             { "crh", "krimska tatar\u0161\u010dina" },
+            { "crj", "jugovzhodna krij\u0161\u010dina" },
+            { "crk", "ni\u017einska krij\u0161\u010dina" },
+            { "crl", "severovzhodna krij\u0161\u010dina" },
+            { "crm", "moose-krij\u0161\u010dina" },
+            { "crr", "karolinska algonkin\u0161\u010dina" },
             { "crs", "sej\u0161elska francoska kreol\u0161\u010dina" },
             { "csb", "ka\u0161ub\u0161\u010dina" },
+            { "csw", "mo\u010dvirska krij\u0161\u010dina" },
             { "dak", "dakot\u0161\u010dina" },
             { "dar", "dargin\u0161\u010dina" },
             { "dav", "taitaj\u0161\u010dina" },
@@ -648,13 +660,16 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "gwi", "gvi\u010din" },
             { "hai", "haid\u0161\u010dina" },
             { "haw", "havaj\u0161\u010dina" },
+            { "hax", "ju\u017ena haid\u0161\u010dina" },
             { "hil", "hiligajnon\u0161\u010dina" },
             { "hit", "hetit\u0161\u010dina" },
             { "hmn", "hmon\u0161\u010dina" },
             { "hsb", "gornja lu\u017ei\u0161ka srb\u0161\u010dina" },
             { "hup", "hupa" },
+            { "hur", "halkomelen\u0161\u010dina" },
             { "iba", "iban\u0161\u010dina" },
             { "ibb", "ibibij\u0161\u010dina" },
+            { "ikt", "zahodna kanadska inuktitu\u0161\u010dina" },
             { "ilo", "ilokan\u0161\u010dina" },
             { "inh", "ingu\u0161\u010dina" },
             { "jbo", "lojban" },
@@ -673,6 +688,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "kde", "makond\u0161\u010dina" },
             { "kea", "zelenortskooto\u0161ka kreol\u0161\u010dina" },
             { "kfo", "koro" },
+            { "kgp", "kaingang\u0161\u010dina" },
             { "kha", "kasi" },
             { "kho", "kotan\u0161\u010dina" },
             { "khq", "koyra chiini" },
@@ -691,16 +707,19 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "ksh", "k\u00f6lnsko nare\u010dje" },
             { "kum", "kumi\u0161\u010dina" },
             { "kut", "kutenaj\u0161\u010dina" },
+            { "kwk", "kvakvala" },
             { "lad", "ladin\u0161\u010dina" },
             { "lag", "langij\u0161\u010dina" },
             { "lah", "landa" },
             { "lam", "lamba" },
             { "lez", "lezgin\u0161\u010dina" },
+            { "lil", "lilovet\u0161\u010dina" },
             { "lkt", "lakot\u0161\u010dina" },
             { "lol", "mongo" },
             { "lou", "louisianska kreol\u0161\u010dina" },
             { "loz", "lozi" },
             { "lrc", "severna lurij\u0161\u010dina" },
+            { "lsm", "saamij\u0161\u010dina" },
             { "lua", "luba-lulua" },
             { "lui", "luisen\u0161\u010dina" },
             { "lun", "lunda" },
@@ -725,6 +744,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "min", "minangkabau" },
             { "mnc", "mand\u017eur\u0161\u010dina" },
             { "mni", "manipur\u0161\u010dina" },
+            { "moe", "inuaimun\u0161\u010dina" },
             { "moh", "moho\u0161\u010dina" },
             { "mos", "mosij\u0161\u010dina" },
             { "mua", "mundang" },
@@ -753,6 +773,11 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "nyn", "njankole" },
             { "nyo", "njoro" },
             { "nzi", "nzima" },
+            { "ojb", "severozahodna o\u010dipvej\u0161\u010dina" },
+            { "ojc", "osrednja o\u010dipvej\u0161\u010dina" },
+            { "ojs", "o\u010di-krij\u0161\u010dina" },
+            { "ojw", "zahodna o\u010dipvej\u0161\u010dina" },
+            { "oka", "okanagan\u0161\u010dina" },
             { "osa", "osage" },
             { "ota", "otomanska tur\u0161\u010dina" },
             { "pag", "pangasinan\u0161\u010dina" },
@@ -762,7 +787,9 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "pcm", "nigerijski pid\u017ein" },
             { "peo", "stara perzij\u0161\u010dina" },
             { "phn", "feni\u010dan\u0161\u010dina" },
+            { "pis", "pid\u017ein" },
             { "pon", "ponpej\u0161\u010dina" },
+            { "pqm", "maliseet-passamaquodd\u0161\u010dina" },
             { "prg", "stara pru\u0161\u010dina" },
             { "pro", "stara provansal\u0161\u010dina" },
             { "quc", "quiche" },
@@ -792,6 +819,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "shi", "tahelitska berber\u0161\u010dina" },
             { "shn", "\u0161an\u0161\u010dina" },
             { "sid", "sidam\u0161\u010dina" },
+            { "slh", "ju\u017ena lu\u0161ucid\u0161\u010dina" },
             { "sma", "ju\u017ena samij\u0161\u010dina" },
             { "smj", "lule\u0161ka samij\u0161\u010dina" },
             { "smn", "inarska samij\u0161\u010dina" },
@@ -800,15 +828,19 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "srn", "surinamska kreol\u0161\u010dina" },
             { "srr", "serer\u0161\u010dina" },
             { "ssy", "saho" },
+            { "str", "o\u017einska sali\u0161\u010dina" },
             { "suk", "sukuma" },
             { "sus", "susuj\u0161\u010dina" },
             { "sux", "sumer\u0161\u010dina" },
             { "swb", "\u0161ikomor" },
             { "syc", "klasi\u010dna sir\u0161\u010dina" },
             { "syr", "sir\u0161\u010dina" },
+            { "tce", "ju\u017ena tu\u010don\u0161\u010dina" },
             { "tem", "temnej\u0161\u010dina" },
             { "teo", "teso" },
             { "tet", "tetum\u0161\u010dina" },
+            { "tgx", "tagi\u0161\u010dina" },
+            { "tht", "taltan\u0161\u010dina" },
             { "tig", "tigrej\u0161\u010dina" },
             { "tiv", "tiv\u0161\u010dina" },
             { "tkl", "tokelav\u0161\u010dina" },
@@ -816,9 +848,11 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "tli", "tlingit\u0161\u010dina" },
             { "tmh", "tamaja\u0161\u010dina" },
             { "tog", "malavijska tong\u0161\u010dina" },
+            { "tok", "toki pona" },
             { "tpi", "tok pisin" },
             { "trv", "taroko" },
             { "tsi", "tsim\u0161\u010dina" },
+            { "ttm", "severna tu\u010don\u0161\u010dina" },
             { "tum", "tumbuk\u0161\u010dina" },
             { "tvl", "tuvaluj\u0161\u010dina" },
             { "twq", "tasawaq" },
@@ -836,12 +870,14 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "war", "varaj\u0161\u010dina" },
             { "was", "va\u0161aj\u0161\u010dina" },
             { "wbp", "varlpir\u0161\u010dina" },
+            { "wuu", "wu-kitaj\u0161\u010dina" },
             { "xal", "kalmi\u0161\u010dina" },
             { "xog", "sog\u0161\u010dina" },
             { "yao", "jaoj\u0161\u010dina" },
             { "yap", "jap\u0161\u010dina" },
             { "yav", "jangben" },
             { "ybb", "jembaj\u0161\u010dina" },
+            { "yrl", "nheengatu" },
             { "yue", "kanton\u0161\u010dina" },
             { "zap", "zapote\u0161\u010dina" },
             { "zbl", "znakovni jezik Bliss" },
@@ -850,7 +886,9 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "zun", "zunij\u0161\u010dina" },
             { "zxx", "brez jezikoslovne vsebine" },
             { "zza", "zazaj\u0161\u010dina" },
+            { "Adlm", "adlamski" },
             { "Arab", "arabski" },
+            { "Aran", "nastalik" },
             { "Armi", "imperialno-aramejski" },
             { "Armn", "armenski" },
             { "Avst", "avestanski" },
@@ -863,6 +901,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "Brai", "braillova pisava" },
             { "Bugi", "buginski" },
             { "Buhd", "buhidski" },
+            { "Cakm", "\u010dakmajski" },
             { "Cans", "poenotena zlogovna pisava kanadskih staroselcev" },
             { "Cher", "\u010deroke\u0161ki" },
             { "Cirt", "kirt" },
@@ -923,8 +962,9 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "Mlym", "malajalamski" },
             { "Mong", "mongolska" },
             { "Moon", "Moonova pisava za slepe" },
-            { "Mtei", "manipurski" },
+            { "Mtei", "meiteiski" },
             { "Mymr", "mjanmarski" },
+            { "Nkoo", "nkojski" },
             { "Ogam", "ogamski" },
             { "Olck", "santalski" },
             { "Orkh", "orkonski" },
@@ -937,6 +977,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "Phlv", "knji\u017eno palavanski" },
             { "Phnx", "feni\u010danski" },
             { "Plrd", "Pollardova fonetska pisava" },
+            { "Rohg", "hanifi" },
             { "Roro", "rongorongo" },
             { "Runr", "runski" },
             { "Samr", "samaritanski" },
@@ -965,6 +1006,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "Visp", "vidni govor" },
             { "Xpeo", "staroperzijski" },
             { "Xsux", "sumersko-akadski klinopis" },
+            { "Yiii", "ji\u0161ki" },
             { "Zinh", "podedovan" },
             { "Zmth", "matemati\u010dna znamenja" },
             { "Zsye", "\u010dustven\u010dek" },
@@ -1044,7 +1086,7 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "type.nu.bali", "balinezijske \u0161tevke" },
             { "type.nu.beng", "bengalske \u0161tevke" },
             { "type.nu.brah", "brahmi \u0161tevke" },
-            { "type.nu.cakm", "\u010dakma \u0161tevke" },
+            { "type.nu.cakm", "\u010dakmajske \u0161tevke" },
             { "type.nu.cham", "Cham \u0161tevke" },
             { "type.nu.cyrl", "cirili\u010dne \u0161tevilke" },
             { "type.nu.deva", "devangarske \u0161tevke" },
@@ -1072,10 +1114,10 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "type.nu.modi", "Modi \u0161tevke" },
             { "type.nu.mong", "Mongolske \u0161tevke" },
             { "type.nu.mroo", "Mro \u0161tevke" },
-            { "type.nu.mtei", "Meetei Mayek \u0161tevke" },
+            { "type.nu.mtei", "meiteiske \u0161tevke" },
             { "type.nu.mymr", "mjanmarske \u0161tevke" },
             { "type.nu.nkoo", "N\u2019Ko \u0161tevke" },
-            { "type.nu.olck", "Ol Chiki \u0161tevke" },
+            { "type.nu.olck", "santalske \u0161tevke" },
             { "type.nu.orya", "orijske \u0161tevke" },
             { "type.nu.osma", "osmanijske \u0161tevke" },
             { "type.nu.saur", "Saurashtra \u0161tevke" },
@@ -1091,29 +1133,29 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "type.nu.thai", "tajske \u0161tevke" },
             { "type.nu.tibt", "tibetanske \u0161tevke" },
             { "type.nu.tirh", "Tirhuta \u0161tevke" },
-            { "type.nu.vaii", "\u0160tevilke vai" },
+            { "type.nu.vaii", "\u0161tevke vai" },
             { "type.nu.wara", "Warang Citi \u0161tevke" },
             { "type.ca.dangi", "stari korejski koledar" },
             { "type.co.ducet", "Privzeto razvr\u0161\u010danje Unicode" },
             { "type.co.emoji", "razvr\u0161\u010danje \u010dustven\u010dkov" },
             { "type.lb.loose", "Prosti slog preloma vrstic" },
             { "type.nu.roman", "rimske \u0161tevilke" },
-            { "type.ca.coptic", "Koptski koledar" },
+            { "type.ca.coptic", "koptski koledar" },
             { "type.ca.hebrew", "hebrejski koledar" },
             { "type.ca.indian", "indijanski koledar" },
             { "type.co.compat", "prej uporabljeno razvr\u0161\u010danje za zdru\u017eljivost" },
             { "type.co.pinyin", "razvr\u0161\u010danje po sistemu pinjin" },
             { "type.co.search", "Splo\u0161no iskanje" },
             { "type.co.stroke", "razvr\u0161\u010danje po zaporedju pisanja pismenk" },
-            { "type.co.unihan", "Razvr\u0161\u010danje koren-poteza" },
-            { "type.co.zhuyin", "Razvr\u0161\u010danje po pismenkah Zhuyin" },
+            { "type.co.unihan", "razvr\u0161\u010danje po radikalih in potezah" },
+            { "type.co.zhuyin", "razvr\u0161\u010danje po pismenkah zhuyin" },
             { "type.d0.fwidth", "Polna \u0161irina" },
             { "type.d0.hwidth", "Polovi\u010dna \u0161irina" },
             { "type.lb.normal", "Obi\u010dajni slog preloma vrstic" },
             { "type.lb.strict", "Strogi slog preloma vrstic" },
             { "type.m0.ungegn", "UNGEGN" },
             { "type.ms.metric", "metri\u010dni sistem" },
-            { "type.nu.native", "Doma\u010de \u0161tevke" },
+            { "type.nu.native", "izvorne \u0161tevke" },
             { "type.ca.chinese", "kitajski koledar" },
             { "type.ca.islamic", "islamski koledar" },
             { "type.ca.iso8601", "koledar ISO-8601" },
@@ -1135,8 +1177,8 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "type.ca.ethiopic", "etiopski koledar" },
             { "type.ca.japanese", "japonski koledar" },
             { "type.cf.standard", "standardna oblika zapisa valute" },
-            { "type.co.phonetic", "Foneti\u010dno razvr\u0161\u010danje" },
-            { "type.co.reformed", "Reformirano razvr\u0161\u010danje" },
+            { "type.co.phonetic", "foneti\u010dno razvr\u0161\u010danje" },
+            { "type.co.reformed", "reformirano razvr\u0161\u010danje" },
             { "type.co.searchjl", "Iskanje po za\u010detnem soglasniku hangul" },
             { "type.co.standard", "Standardno razvr\u0161\u010danje" },
             { "type.ms.uksystem", "imperialni merski sistem" },
@@ -1152,15 +1194,15 @@ public class LocaleNames_sl extends OpenListResourceBundle {
             { "type.nu.romanlow", "rimske male \u0161tevilke" },
             { "type.ca.gregorian", "gregorijanski koledar" },
             { "type.co.gb2312han", "razvr\u0161\u010danje po sistemu poenostavljene kitaj\u0161\u010dine - GB2312" },
-            { "type.co.phonebook", "razvr\u0161\u010danje po abecedi" },
-            { "type.co.dictionary", "Vrstni red razvr\u0161\u010danja v slovarju" },
+            { "type.co.phonebook", "razvr\u0161\u010danje po sistemu telefonskega imenika" },
+            { "type.co.dictionary", "slovarsko razvr\u0161\u010danje" },
             { "type.co.traditional", "razvr\u0161\u010danje po tradicionalnem sistemu" },
             { "type.nu.traditional", "Tradicionalne \u0161tevilke" },
             { "type.ca.islamic-rgsa", "islamski koledar ( Saudova Arabija, opazovalni)" },
             { "type.ca.islamic-tbla", "islamski koledar (tabelarni, astronomska epoha)" },
             { "type.ca.islamic-civil", "islamski civilni koledar" },
             { "type.ca.islamic-umalqura", "islamski koledar Umm al-Qura" },
-            { "type.ca.ethiopic-amete-alem", "Etiopsko ametsko alemski koledar" },
+            { "type.ca.ethiopic-amete-alem", "etiopsko ametsko alemski koledar" },
         };
         return data;
     }
