@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -777,7 +777,6 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             { "Asia/Baku", Azerbaijan },
             { "Asia/Gaza", Europe_Eastern },
             { "Asia/Omsk", Omsk },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
             { "Asia/Dubai", Gulf },
@@ -851,7 +850,6 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             { "America/Jujuy", Argentina },
             { "America/Thule", Atlantic },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
             { "Asia/Khandyga", Yakutsk },
@@ -1110,6 +1108,7 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             { "America/Scoresbysund", Greenland_Eastern },
             { "Antarctica/Macquarie", Australia_Eastern },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
