@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -1287,7 +1287,6 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1383,7 +1382,6 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1695,6 +1693,7 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -2125,6 +2124,7 @@ public class TimeZoneNames_sr_Latn extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Bougainville", "Buganvil" },
             { "timezone.excity.Pacific/Port_Moresby", "Port Morzbi" },
             { "timezone.excity.America/Cambridge_Bay", "Kembrid\u017e Bej" },
+            { "timezone.excity.America/Ciudad_Juarez", "Siudad Huarez" },
             { "timezone.excity.America/Coral_Harbour", "Koral Harbur" },
             { "timezone.excity.America/Indiana/Vevay", "Vevaj, Indijana" },
             { "timezone.excity.America/Lower_Princes", "Louer Prinsiz Kvorter" },
