@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -1295,7 +1295,6 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1391,7 +1390,6 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1704,6 +1702,7 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1913,6 +1912,7 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Mayotte", "\u9a6c\u7ea6\u7279\u5c9b" },
             { "timezone.excity.Indian/Reunion", "\u7559\u5c3c\u65fa\u5c9b" },
             { "timezone.excity.Pacific/Easter", "\u590d\u6d3b\u5c9b" },
+            { "timezone.excity.Pacific/Kanton", "\u574e\u987f" },
             { "timezone.excity.Pacific/Kosrae", "\u79d1\u65af\u745e" },
             { "timezone.excity.Pacific/Majuro", "\u9a6c\u6731\u8bfa" },
             { "timezone.excity.Pacific/Midway", "\u4e2d\u9014\u5c9b" },
@@ -2133,6 +2133,7 @@ public class TimeZoneNames_yue_Hans extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Bougainville", "\u5e03\u5e72\u7ef4\u5c14" },
             { "timezone.excity.Pacific/Port_Moresby", "\u83ab\u58eb\u6bd4\u6e2f" },
             { "timezone.excity.America/Cambridge_Bay", "\u5251\u6865\u6e7e" },
+            { "timezone.excity.America/Ciudad_Juarez", "\u534e\u96f7\u65af\u57ce" },
             { "timezone.excity.America/Coral_Harbour", "\u963f\u8482\u79d1\u80af" },
             { "timezone.excity.America/Indiana/Vevay", "\u5370\u7b2c\u5b89\u90a3\u5dde\u7ef4\u5a01" },
             { "timezone.excity.America/Lower_Princes", "\u4e0b\u592a\u5b50\u533a" },
